pub struct OpenKey<CS: CipherSuite> { /* private fields */ }Available on crate feature
afc only.Expand description
A decryption key.
Implementations
Sourceimpl<CS: CipherSuite> OpenKey<CS>
impl<CS: CipherSuite> OpenKey<CS>
Sourcepub const OVERHEAD: usize = OpenCtx<CS::Aead>::OVERHEAD
pub const OVERHEAD: usize = OpenCtx<CS::Aead>::OVERHEAD
The size in bytes of the overhead added to the plaintext.
Sourcepub fn from_raw(key: &RawOpenKey<CS>) -> Result<Self, ImportError>
pub fn from_raw(key: &RawOpenKey<CS>) -> Result<Self, ImportError>
Creates decryption key from a raw key.
Sourcepub fn open(
&self,
dst: &mut [u8],
ciphertext: &[u8],
ad: &AuthData,
seq: Seq,
) -> Result<(), OpenError>
pub fn open( &self, dst: &mut [u8], ciphertext: &[u8], ad: &AuthData, seq: Seq, ) -> Result<(), OpenError>
Decrypts and authenticates ciphertext at a particular
sequence number.
The resulting plaintext is written to dst, which must
must be at least ciphertext.len() - OVERHEAD
bytes long.
Sourcepub fn open_in_place(
&self,
data: impl AsMut<[u8]>,
tag: &[u8],
ad: &AuthData,
seq: Seq,
) -> Result<(), OpenError>
pub fn open_in_place( &self, data: impl AsMut<[u8]>, tag: &[u8], ad: &AuthData, seq: Seq, ) -> Result<(), OpenError>
Decrypts and authenticates ciphertext at a particular
sequence number.
The resulting plaintext is written to dst, which must
must be at least ciphertext.len() - OVERHEAD
bytes long.