DefaultEngine

Struct DefaultEngine 

pub struct DefaultEngine<R: Csprng = Rng, S: CipherSuite = DefaultCipherSuite> { /* private fields */ }
A basic Engine implementation that wraps keys with its Aead.

Implementations

Source

impl<R: Csprng, S: CipherSuite> DefaultEngine<R, S>

pub fn new(key: &<S::Aead as Aead>::Key, rng: R) -> Self

Creates an Engine using key.

pub fn from_entropy(rng: R) -> (Self, <S::Aead as Aead>::Key)

Creates an Engine using entropy from rng and returns it and the generated key.