WrappedKey

Trait WrappedKey 

pub trait WrappedKey:
    Identified
    + Serialize
    + DeserializeOwned
    + Sized { }
An encrypted, authenticated key created by Engine::wrap that can only be decrypted by Engine::unwrap.

It need not directly contain the ciphertext. For example, it might only contain an identifier used to look up the key in an HSM.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors